// Copyright 2022 Alibaba Group Holding Limited.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#ifndef Jcp_PORT_H
#define Jcp_PORT_H

/* If no external linkage macros defined by now, create defaults */
#ifndef JcpAPI_FUNC
    #define JcpAPI_FUNC(RTYPE) Jcp_EXPORTED_SYMBOL RTYPE
#endif
#ifndef JcpAPI_DATA
    #define JcpAPI_DATA(RTYPE) extern Jcp_EXPORTED_SYMBOL RTYPE
#endif

#endif
